==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/architecture/classes/ModelInstSet.java <==
package io.ciera.tool.sql.architecture.classes;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.AttributeSet;
import io.ciera.tool.sql.architecture.classes.ClassRelationshipSet;
import io.ciera.tool.sql.architecture.classes.InstSetSet;
import io.ciera.tool.sql.architecture.classes.InstanceSelectorSet;
import io.ciera.tool.sql.architecture.classes.OperationSet;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.InstancePopulationSelectorSet;
import io.ciera.tool.sql.architecture.expression.CreationSet;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.statemachine.StateMachineSet;
import io.ciera.tool.sql.architecture.type.TypeSet;
import io.ciera.tool.sql.loader.EventInstanceLoaderSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;


public interface ModelInstSet extends IInstanceSet<ModelInstSet,ModelInst> {

    // attributes
    public void setKey_letters( String m_key_letters ) throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public void setExtends( String m_extends ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;


    // selections
    public EventInstanceLoaderSet R3017_EventInstanceLoader() throws XtumlException;
    public FileSet R401_is_a_File() throws XtumlException;
    public InstSetSet R406_is_type_of_single_element_in_InstSet() throws XtumlException;
    public TypeSet R407_is_a_Type() throws XtumlException;
    public ComponentDefinitionSet R408_forms_instance_population_of_ComponentDefinition() throws XtumlException;
    public ModelClassSet R409_is_transformed_from_ModelClass() throws XtumlException;
    public AttributeSet R410_data_abstracted_by_Attribute() throws XtumlException;
    public OperationSet R416_provides_Operation() throws XtumlException;
    public ClassRelationshipSet R434_participates_in_ClassRelationship() throws XtumlException;
    public ClassRelationshipSet R435_formalizes_ClassRelationship() throws XtumlException;
    public InstanceSelectorSet R442_selects_instances_through_InstanceSelector() throws XtumlException;
    public InstancePopulationSelectorSet R449_extent_accessed_by_InstancePopulationSelector() throws XtumlException;
    public StateMachineSet R4750_behavior_modeled_by_StateMachine() throws XtumlException;
    public CreationSet R780_created_by_Creation() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/classes/ModelInstSet.java <==
package io.ciera.tool.sql.architecture.classes;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.classes.AttributeSet;
import io.ciera.tool.sql.architecture.classes.ClassRelationshipSet;
import io.ciera.tool.sql.architecture.classes.InstSetSet;
import io.ciera.tool.sql.architecture.classes.InstanceSelectorSet;
import io.ciera.tool.sql.architecture.classes.OperationSet;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.component.InstancePopulationSelectorSet;
import io.ciera.tool.sql.architecture.expression.CreationSet;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.statemachine.StateMachineSet;
import io.ciera.tool.sql.architecture.type.TypeSet;
import io.ciera.tool.sql.loader.EventInstanceLoaderSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;


public interface ModelInstSet extends IInstanceSet<ModelInstSet,ModelInst> {

    // attributes
    public void setPackage( String ref_package ) throws XtumlException;
    public void setExtends( String m_extends ) throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public void setComparator( String m_comparator ) throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public void setKey_letters( String m_key_letters ) throws XtumlException;
    public void setUnmanaged( boolean m_unmanaged ) throws XtumlException;


    // selections
    public EventInstanceLoaderSet R3017_EventInstanceLoader() throws XtumlException;
    public FileSet R401_is_a_File() throws XtumlException;
    public InstSetSet R406_is_type_of_single_element_in_InstSet() throws XtumlException;
    public TypeSet R407_is_a_Type() throws XtumlException;
    public ComponentDefinitionSet R408_forms_instance_population_of_ComponentDefinition() throws XtumlException;
    public ModelClassSet R409_ModelClass() throws XtumlException;
    public AttributeSet R410_data_abstracted_by_Attribute() throws XtumlException;
    public OperationSet R416_provides_Operation() throws XtumlException;
    public ClassRelationshipSet R434_participates_in_ClassRelationship() throws XtumlException;
    public ClassRelationshipSet R435_formalizes_ClassRelationship() throws XtumlException;
    public InstanceSelectorSet R442_selects_instances_through_InstanceSelector() throws XtumlException;
    public InstancePopulationSelectorSet R449_extent_accessed_by_InstancePopulationSelector() throws XtumlException;
    public StateMachineSet R4750_behavior_modeled_by_StateMachine() throws XtumlException;
    public CreationSet R780_created_by_Creation() throws XtumlException;


}
